import * as angular from 'angular';
import AddContentWorkflowCore from '@meltwater/add-content-workflow-core';

export default class AddContentDialogComponent {
    currentStep: string = 'source';
    tncText: string;
    tncCopy: string;
    tncMarkup: string;
    workflow: AddContentWorkflowCore.Workflow;

    static config = {
        selector: 'addContentDialog',
        template: `
            <mw-mini-modal-dialog class="add-content-workflow" layout="column" data="$ctrl.user" cancel="Cancel">
                <mw-modal-header layout="row" layout-align="center center" flex>
                    <mw-modal-header-title>{{$ctrl.AddContentTranslate.get($ctrl.workflow.title)}}</mw-modal-header-title>
                    <div flex=""></div>
                    <mw-modal-header-title class="mw-pad-right" ng-if="$ctrl.workflow.currentStep === 'details'">{{$ctrl.translateDocCount()}}</mw-modal-header-title>
                </mw-modal-header>
                <mw-modal-alert-message layout="column" ng-if="$ctrl.workflow.shouldValidateForm || $ctrl.workflow.shouldValidateTermsAndConditions || $ctrl.workflow.errorAddingContent">
                    <div ng-if="$ctrl.workflow.shouldValidateForm && !$ctrl.workflow.shouldValidateTermsAndConditions">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--field-error')}}
                    </div>
                    <div ng-if="!$ctrl.workflow.shouldValidateForm && $ctrl.workflow.shouldValidateTermsAndConditions">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--terms-error')}}
                    </div>
                    <div ng-if="$ctrl.workflow.shouldValidateForm && $ctrl.workflow.shouldValidateTermsAndConditions">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--field-and-terms-error')}}
                    </div>
                    <div ng-if="$ctrl.workflow.errorAddingContent">
                        {{::$ctrl.AddContentTranslate.get('add-content-workflow__dialog--save-content-error-message')}}
                    </div>
                </mw-modal-alert-message>
                <mw-modal-content>
                    <add-content-workflow workflow="$ctrl.workflow"></add-content-workflow>
                </mw-modal-content>
                <mw-modal-footer layout="row" layout-align="center center" flex>
                    <md-checkbox ng-if="$ctrl.workflow.shouldShowTermsAndConditions()" required class="md-primary" ng-model="$ctrl.workflow.userAgreementChecked">
                        <span ng-bind-html="$ctrl.tncMarkup"></span>
                    </md-checkbox>
                    <div flex=""></div>
                    <md-button ng-click="$ctrl.cancel($event)" class="mw-mini-modal__cancel-button mw-button">{{::$ctrl.AddContentTranslate.get('add-content-workflow__dialog—cancel--button')}}</md-button>
                    <md-button ng-click="$ctrl.workflow.nextStep()" class="mw-mini-modal__ok-button mw-button" ng-disabled="$ctrl.workflow.loading">
                        <md-progress-circular ng-if="$ctrl.workflow.loading || $ctrl.workflow.savingAddContent"
                            md-diameter="16px"
                            style="margin: 0 auto"></md-progress-circular>
                        <span ng-if="!$ctrl.workflow.loading && !$ctrl.workflow.savingAddContent"">{{$ctrl.AddContentTranslate.get($ctrl.workflow.okLabel)}}</span>
                    </md-button>
                </mw-modal-footer>
            </mw-mini-modal-dialog>
        `,
        controller: AddContentDialogComponent,
        bindings: {
            workflow: '<'
        },
    };

    /*@ngInject*/
    constructor(
        private $mdDialog,
        private $timeout,
        private $sce,
        private $scope,
        private $compile,
        private AddContentTranslate
    ) {

    }

    $onInit() {
        this.tncText = '';
        this.$scope.$watch(() => this.workflow.currentStep,
            (newValue, oldValue) => {
                // Don't translate if we're on the source step or not showing the terms line
                if (newValue === 'details' || !this.workflow.shouldShowTermsAndConditions()) return;
                this.translateTermsAndConditions();
            });
    }

    translateDocCount() {
        return this.AddContentTranslate.get('add-content-workflow__dialog--document-count', {
            current: this.workflow.currentIndex+1,
            total: this.workflow.documents.length
        });
    }

    translateTermsAndConditions() {
        this.tncCopy = this.AddContentTranslate.get('add-content-workflow__details-step--terms-conditions-tooltip').replace(/\u00A0/g,' '); // Replacing nbsp
        this.tncMarkup = this.AddContentTranslate.get('add-content-workflow__details-step--terms-conditions-checkbox', {
            openingTag: '<span class="add-content-workflow__terms-link mw-aqua">',
            closingTag: '</span>'
        }).replace(/&gt;/g, '>').replace(/&lt;/g, '<');

        // Using timeout to hold execution for DOM rendering
        this.$timeout(() => {
            let scope;

            // Grab the span tag and make into an angular element
            let el = angular.element(document.getElementsByClassName('add-content-workflow__terms-link')[0]);

            // Create the tooltip element and append to the anchor element
            let tooltip = angular.element(`
                <md-tooltip md-direction="top" class="mw-infotip">${this.tncCopy}</md-tooltip>
            `);
            el.append(tooltip);

            // Compile
            scope = el.scope();
            this.$compile(el)(scope);
        });
    }

    cancel() {
        this.$mdDialog.cancel();
    }
}
