export default class InputSelectorDialogComponent {
    static config = {
        selector: 'inputSelectorDialog',
        template: `
            <mw-mini-modal-dialog class="add-content-input-selector mw-mini-modal-dialog" 
                layout="column" data="$ctrl.inputs" 
                title="{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--tag-modal-title')}}" 
                no-padding="true"
                ok="{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--save-button')}}" 
                cancel="{{::$ctrl.AddContentTranslate.get('add-content-workflow__dialog—cancel--button')}}" 
                on-ok="$ctrl.handleOk($event)" 
                on-cancel="$ctrl.handleCancel($event)">
                    <mw-modal-header>
                        <mw-modal-header-title>{{$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--tag-modal-title')}} ({{$ctrl.countSelected()}}/{{$ctrl.inputs.length}})</mw-modal-header-title>
                        <div flex=""></div>
                    </mw-modal-header>
                    <mw-modal-find>
                        <mw-find search="$ctrl.searchModel" debounce="300" placeholder="{{::$ctrl.AddContentTranslate.get('mw-collection-search__find')}}"></mw-find>
                    </mw-modal-find>
                    <mw-modal-content class="mw-menu-dialog mw-menu--has-find">
                        <mw-menu-subheader ng-show="$ctrl.searchModel.length && $ctrl.searchModel.length >= $ctrl.minSearchLength">
                            <span ng-if="$ctrl.filterCount() === 0">{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-no-results')}}</span>
                            <span ng-if="$ctrl.filterCount() === 1">{{::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-one-result')}}</span>
                            <span ng-if="$ctrl.filterCount() > 1">{{ ::$ctrl.AddContentTranslate.get('add-content-workflow__tags-modal--search-results', {numResults: $ctrl.filterCount()}) }} </span>
                        </mw-menu-subheader>
     
                        <mw-menu-item ng-repeat="input in filteredInputs = ($ctrl.inputs | filter: {type:'tag'} | filter: {display: $ctrl.searchModel})"
                                      aria-label="input.display"
                                      is-selected="input.selected"
                                      on-click="input.selected = !input.selected"
                                      type="multiselect">
                            {{input.display}}
                        </mw-menu-item>
                    </mw-modal-content>
            </mw-mini-modal-dialog>
        `,
        bindings: {
            inputs: '<'
        },
        controller: InputSelectorDialogComponent
    };

    searchModel: string;
    inputs: any;
    minSearchLength: number;

    /*@ngInject*/
    constructor(
        private $mdDialog,
        private $filter,
        private AddContentTranslate
    ) {
        this.searchModel = '';
        this.minSearchLength = 1;
    }

    handleOk(event) {
        this.$mdDialog.hide(this.inputs);
    };

    handleCancel(event) {
        this.$mdDialog.cancel();
    };

    countSelected() {
        return this.inputs.filter(tag => tag.selected).length;
    }

    filterCount() {
        return this.$filter('filter')(this.inputs, {display: this.searchModel}).length
    }

}
